
library(gombedatabase)
library(lubridate)
library(dplyr)
library(tidyr)
library(lmerTest)
library(glmmTMB)
library(MuMIn)

# ------------ analysis dataset ------------------------
analysis_dat = read.csv("analysis_data_anon.csv", header = T, stringsAsFactors = F)

# ensure no NA values in the analysis data:
sapply(analysis_dat, function(x) sum(is.na(x))) 

head(analysis_dat)

# base model:
m0 = glmer(sire ~
             age +
             id1_elo11 +
             qgr +
             (1|id1)
           , 
           family = "binomial",
           data = analysis_dat, na.action = na.fail)

summary(m0)

simout = DHARMa::simulateResiduals(m0)
plot(simout)

# base model plus personality traits

m_dom = update(m0, ~ . + dom_z)
m_cons = update(m0, ~ . + consc_z)
m_both = update(m0, ~ . + dom_z + consc_z)
m_all = update(m0, ~ . + dom_z + consc_z + extra_z +
                 agree_z + neuro_z + open_z, nAGQ = 0)

# age- and rank-specific effects of dom and consc

m_dom2 = update(m0, ~ . + dom_z*age, nAGQ = 0)
m_cons2 = update(m0, ~ . + consc_z*age)
m_dom3 = update(m0, ~ . + dom_z*id1_elo11)
m_cons3 = update(m0, ~ . + consc_z*id1_elo11)

# squared effect of dom and consc

m_dom_sq = update(m0, ~ . + dom_z + I(dom_z^2), nAGQ = 0)
m_dom_sq2 = update(m0, ~ . + dom_z*age + I(dom_z^2), nAGQ = 0)
m_dom_sq3 = update(m0, ~ . + dom_z*age + I(dom_z^2)*age, nAGQ = 0)

m_cons_sq = update(m0, ~ . + consc_z + I(consc_z^2))
m_cons_sq2 = update(m0, ~ . + consc_z*age + I(consc_z^2), nAGQ = 0)


# ------------------ compare models ----------------------

AICc(m0, # null
     m_dom, # just DOMINANCE
     m_cons, # just CONSCIENTIOUSNESS
     m_both, # DOMINANCE + CONSCIENTIOUSNESS
     m_all, # all six traits
     m_dom2, # DOMINANCE * age
     m_cons2, # CONSCIENTIOUSNESS * age
     m_dom3, # DOMINANCE * elo
     m_cons3, # CONSCIENTIOUSNESS * elo
     m_dom_sq, # DOMINANCE + DOMINANCE ^2
     m_dom_sq2, # DOMINANCE * age + DOMINANCE ^2
     m_dom_sq3,  # DOMINANCE * age + DOMINANCE ^2 * age
     m_cons_sq, # CONSCIENTIOUSNESS + CONSCIENTIOUSNESS ^2
     m_cons_sq2 # CONSCIENTIOUSNESS * age + CONSCIENTIOUSNESS ^2 
) %>% 
  arrange(AICc) %>% 
  mutate(mod = row.names(.),
         delta = min(AICc) - AICc, 
         weights = MuMIn::Weights(AICc)) %>%
  select(mod, everything()) %>%
  mutate(AICc = round(AICc, 3),
         delta = round(delta, 3),
         weights = round(weights, 3)) 

summary(m_dom_sq)
summary(m_dom_sq2)

# check model assumptions
simout = DHARMa::simulateResiduals(m_dom_sq)
plot(simout)

performance::check_collinearity(m_dom_sq)


# ------------------- plotting ----------------

library(sjPlot)
library(ggplot2)
library(ggpubr)


pa =
  plot_model(m_dom_sq, type = "pred", 
             terms = c("age [all]",
                       "dom_z [-1.5, 0, 1.5]"), line.size = 1.2) +
  xlab("Male age") + 
  ylab("Predicted prob. of siring given offspring") + 
  scale_color_discrete(name = "Dominance", labels = c("Low", "Mid", "High")) +
  scale_x_continuous(breaks = c(-1, 0, 1, 2), labels = c(14, 21, 29, 37)) + # back-transform scaled ages
  theme(legend.position="top") +
  ggtitle(element_blank()) +
  scale_y_continuous(limits = c(0, 0.33),
                     breaks = c(0, 0.1, 0.2, 0.3),
                     labels = c("0%", "10%", "20%", "30%"))


pb =
  plot_model(m_dom_sq, type = "pred", 
             terms = c("dom_z [all]",
                       "id1_elo11 [-1.5, 0, 1.71519]"), line.size = 1.2) + # back-transforming scaled Elo scores to Cardinal elo scores
  aes(color = group) + 
  xlab("Dominance (personality trait)") + 
  ylab(" ") + 
  scale_color_discrete(name = "Elo score", 
                       labels = c("0.1", "0.5", "1")) +
  scale_linetype_discrete(name = "Elo score", labels = c("0.1", "0.5", "1")) +
  theme(legend.position="top") +
  ggtitle(element_blank()) +
  scale_y_continuous(limits = c(0, 0.33),
                     breaks = c(0, 0.1, 0.2, 0.3),
                     labels = c("0%", "10%", "20%", "30%"))


ggarrange(pa, pb,
          labels = c("A", "B"),
          ncol = 2)



